Gemeinde Adressverwaltung GUI: Elementverzeichnis

Gemeinde Adressverwaltung GUI

Gemeinde_Modelle.Familie Elementverzeichnis

Vollständige Aufstellung aller Elemente für Gemeinde_Modelle.Familie einschließlich aller geerbten Elemente.

__init__(self, id=None, holen=False) (Definiert in Gemeinde_Modelle.Familie) | Gemeinde_Modelle.Familie |
__str__(self) (Definiert in Gemeinde_Modelle.Familie) | Gemeinde_Modelle.Familie |
keyFeldNavi (Definiert in Gemeinde_Modelle.Familie) | Gemeinde_Modelle.Familie | static
R_anrede (Definiert in Gemeinde_Modelle.Familie) | Gemeinde_Modelle.Familie | static